Struct amazon_sp_fulfillment_inbound::models::inbound_shipment_plan::InboundShipmentPlan
source · [−]pub struct InboundShipmentPlan {
pub shipment_id: String,
pub destination_fulfillment_center_id: String,
pub ship_to_address: Box<Address>,
pub label_prep_type: LabelPrepType,
pub items: Vec<InboundShipmentPlanItem>,
pub estimated_box_contents_fee: Option<Box<BoxContentsFeeDetails>>,
}Expand description
InboundShipmentPlan : Inbound shipment information used to create an inbound shipment. Returned by the createInboundShipmentPlan operation.
Fields
shipment_id: StringA shipment identifier originally returned by the createInboundShipmentPlan operation.
destination_fulfillment_center_id: StringAn Amazon fulfillment center identifier created by Amazon.
ship_to_address: Box<Address>label_prep_type: LabelPrepTypeitems: Vec<InboundShipmentPlanItem>A list of inbound shipment plan item information.
estimated_box_contents_fee: Option<Box<BoxContentsFeeDetails>>Implementations
sourceimpl InboundShipmentPlan
impl InboundShipmentPlan
sourcepub fn new(
shipment_id: String,
destination_fulfillment_center_id: String,
ship_to_address: Address,
label_prep_type: LabelPrepType,
items: Vec<InboundShipmentPlanItem>
) -> InboundShipmentPlan
pub fn new(
shipment_id: String,
destination_fulfillment_center_id: String,
ship_to_address: Address,
label_prep_type: LabelPrepType,
items: Vec<InboundShipmentPlanItem>
) -> InboundShipmentPlan
Inbound shipment information used to create an inbound shipment. Returned by the createInboundShipmentPlan operation.